<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui library="kofficescan" version="1">
<MenuBar>
    <Menu name="Tools"><text>Tools</text>
	<Seperator/>
	<Action name="scan_image"/>
    </Menu>
</MenuBar>
</kpartgui>
