<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" >
<kpartgui name="KivioConnectorTool" library="libkivioconnectortool" version="2">
<MenuBar>
  <Menu name="Tools">
    <Action name="connector"/>
  </Menu>
</MenuBar>
</kpartgui>
