<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" ><kpartgui name="KFormula" version="3">
<MenuBar>
 <Menu name="Edit"><text>&amp;Edit</text>
  <Action name="koffice_undo"/>
  <Action name="koffice_redo"/>
  <Separator/>
  <Action name="edit_cut"/>
  <Action name="edit_copy"/>
  <Action name="edit_paste"/>
  <Separator/>
  <Action name="edit_select_all"/>
  <Action name="formula_removeenclosing"/>
  <Action name="formula_makegreek"/>
  <Action name="formula_formulastring"/>
 </Menu>
 <Menu name="Element"><text>E&amp;lement</text>
  <Menu name="Add"><text>Add</text>
  <Action name="formula_addtext"/>
  <Action name="formula_addroot"/>
  <Action name="formula_addfrac"/>
  <Action name="formula_addbra"/>
  <Action name="formula_addintegral"/>
  <Action name="formula_addsum"/>
  <Action name="formula_addproduct"/>
  <Action name="formula_addmatrix"/>
  <Action name="formula_add_one_by_two_matrix"/>
  <Action name="formula_addoverline"/>
  <Action name="formula_addunderline"/>
  <Action name="formula_addmultiline"/>
  <Separator/>
  <Action name="formula_addupperindex"/>
  <Action name="formula_addlowerindex"/>
  <Separator/>
  <Action name="formula_addnegthinspace"/>
  <Action name="formula_addthinspace"/>
  <Action name="formula_addmediumspace"/>
  <Action name="formula_addthickspace"/>
  <Action name="formula_addquadspace"/>
  </Menu>
  <Menu name="matrix"><text>Matrix</text>
   <Action name="formula_insertcolumn"/>
   <Action name="formula_appendcolumn"/>
   <Action name="formula_removecolumn"/>
   <Action name="formula_insertrow"/>
   <Action name="formula_appendrow"/>
   <Action name="formula_removerow"/>
  </Menu>
  <Action name="formula_textsize"/>

  <Action name="formula_typeleft"/>
  <Action name="formula_typeright"/>
  <Action name="formula_insertsymbol"/>
 </Menu>
<!--
 <Menu name="Font"><text>Font</text>
  <Action name="textfont"/>
  <Action name="textsize"/>
  <Action name="textbold"/>
  <Action name="textitalic"/>
  <Action name="textunder"/>
  <Menu name="scale"><text>Increase/Decrease Options..</text>
  <Action name="fontelement"/>
  <Action name="fontindex"/>
  <Action name="fontchild"/>
  <Action name="fontnext"/>

  </Menu>
 </Menu>
-->
 <Menu name="settings"><text>&amp;Settings</text>
  <Separator group="settings_show"/>
  <Action name="formula_syntaxhighlighting" group="settings_show"/>
  <Separator group="settings_show"/>
  <Action name="configure" group="settings_configure"/>
 </Menu>

  <Menu name="help">
   <Action name="help_show_tip"/>
  </Menu>
</MenuBar>

 <ToolBar fullWidth="false" name="edit_toolbar" position="top"><Text>Edit</Text>
  <Action name="koffice_undo"/>
  <Action name="koffice_redo"/>
  <Separator/>
  <Action name="edit_cut"/>
  <Action name="edit_copy"/>
  <Action name="edit_paste"/>
 </ToolBar>
 <ToolBar name="Add"><Text>Add</Text>
  <Action name="formula_addtext"/>
  <Action name="formula_addroot"/>
  <Action name="formula_addfrac"/>
  <Action name="formula_addbra"/>
  <Action name="formula_addsqrbra"/>
  <Action name="formula_addcurbra"/>
  <Action name="formula_addabsbra"/>
  <Action name="formula_addoverline"/>
  <Action name="formula_addunderline"/>
  <Action name="formula_addintegral"/>
  <Action name="formula_addsum"/>
  <Action name="formula_addproduct"/>
  <Action name="formula_addmatrix"/>
  <Action name="formula_add_one_by_two_matrix"/>
  <Action name="formula_addupperleft"/>
  <Action name="formula_addlowerleft"/>
  <Action name="formula_addupperright"/>
  <Action name="formula_addlowerright"/>
  <Action name="formula_addmultiline"/>
  <Separator/>
  <Action name="formula_typeleft"/>
  <Action name="formula_typeright"/>
 </ToolBar>
 <ToolBar name="Font"><Text>Font</Text>
  <Action name="formula_textsize"/>
  <Separator/>
  <Action name="formula_format_bold"/>
  <Action name="formula_format_italic"/>
  <Separator/>
  <Action name="formula_fontfamily"/>
 </ToolBar>
<!--
 <ToolBar name="Element"><Text>Element</Text>
  <Action name="textsplit"/>
  <Action name="rootindex"/>
  <Action name="typeleft"/>
  <Action name="typeright"/>
  <Action name="fracup"/>
  <Action name="fracmiddle"/>
  <Action name="fracdown"/>
  <Action name="fracleft"/>
  <Action name="fraccenter"/>
  <Action name="fracright"/>
  <Action name="fracmidline"/>
  <Action name="fracnear"/>
  <Action name="fracfar"/>
  <Action name="ihigher"/>
  <Action name="ilower"/>
  <Action name="matrixset"/>
  <Action name="matrixinsrow"/>
  <Action name="matrixinscol"/>
  <Action name="matrixremrow"/>
  <Action name="matrixremcol"/>
 </ToolBar>
-->
 <ToolBar name="Symbol"><Text>Symbol</Text>
  <Action name="formula_symbolnames"/>
  <Action name="formula_insertsymbol"/>
 </ToolBar>
 <ToolBar name="Matrix"><Text>Matrix</Text>
  <Action name="formula_insertcolumn"/>
  <Action name="formula_appendcolumn"/>
  <Action name="formula_removecolumn"/>
  <Action name="formula_insertrow"/>
  <Action name="formula_appendrow"/>
  <Action name="formula_removerow"/>
 </ToolBar>
</kpartgui>
