<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" ><kpartgui name="KSpread" version="14">
<MenuBar>
 <Menu name="file"><text>&amp;File</text>
  <Separator/>
  <Action name="createTemplate"/>
 </Menu>
 <Menu name="Edit"><text>&amp;Edit</text>
  <Action name="undo"/>
  <Action name="redo"/>
  <Separator/>
  <Action name="cut"/>
  <Action name="copy"/>
  <Action name="paste"/>
  <Action name="specialPaste"/>
  <Action name="insertCellCopy"/>
  <Menu name="Fill"><text>Fi&amp;ll</text>
        <Action name="fillDown"/>
        <Action name="fillRight"/>
        <Action name="fillUp"/>
        <Action name="fillLeft"/>
  </Menu>      
  <Separator/>
  <Action name="edit_find"/>
  <Action name="edit_find_next"/>
  <Action name="edit_find_last"/>
  <Action name="edit_replace"/>
  <Menu name="Clear"><text>Clear</text>
        <Action name="cleartext"/>
        <Action name="clearcomment"/>
        <Action name="clearvalidity"/>
        <Action name="clearconditional"/>
  </Menu>
  <Action name="delete"/>
  <Separator/>
  <Action name="conditional"/>
  <Action name="validity"/>
  <Action name="editCell"/>
  <Separator/>
  <Action name="transform"/>
 </Menu>
 <Menu name="View"><text>&amp;View</text>
  <Action name="view_newview"/>
  <ActionList name="view_closeallviews"/>
  <Separator/>
  <ActionList name="view_split" />
  <Action name="gotoCell"/>
  <Action name="showPageBorders"/>
  <Separator/>
  <Action name="view_zoom"/>
 </Menu>
 <Menu name="Insert"><text>&amp;Insert</text>
  <Action name="menuInsertTable"/>
  <Separator/>       
  <Menu name="Comment"><text>Cell Commen&amp;t</text>
    <Action name="addmodifycomment"/>
    <Action name="showcomment"/>
    <Action name="removecomment"/>
  </Menu>
  <Action name="insertMathExpr"/>
  <Action name="insertFormula"/>
  <Action name="series"/>
  <Action name="insertHyperlink"/>
  <Action name="insertSpecialChar"/>
  <Separator/>       
  <Action name="insertPart"/>
  <Action name="insertChart"/>
  <Separator/>
  <Menu name="ExternalData"><text>&amp;External Data</text>
    <Action name="insertFromDatabase"/>
    <Action name="insertFromTextfile"/>
    <Action name="insertFromClipboard"/>
  </Menu>        
 </Menu>
 <Menu name="Format"><text>F&amp;ormat</text>
  <Action name="cellLayout"/>
  <Action name="paperLayout"/>
  <Menu name="Comment"><text>&amp;Print Range</text>
    <Action name="definePrintRange"/>
    <Action name="resetPrintRange"/>
  </Menu>
  <Separator/>
  <Menu name="Sheet"><text>&amp;Sheet</text>
  <Action name="removeTable"/>
  <Action name="hideTable"/>
  <Action name="showTable"/>
  </Menu>
  <Separator/>
  <Action name="adjust"/>
  <Menu name="Row"><text>&amp;Row</text>
    <Action name="resizeRow"/>
    <Action name="equalizeRow"/>
    <Action name="hideRow"/>
    <Action name="showRow"/>
  </Menu>
  <Menu name="Column"><text>&amp;Column</text>
    <Action name="resizeCol"/>
    <Action name="equalizeCol"/>
    <Action name="hideColumn"/>
    <Action name="showColumn"/>
  </Menu>
  <Separator/>
  <Action name="tableFormat"/>
  <Action name="styles"/>  
  <Action name="stylemenu"/>
  <Action name="createStyle"/>        
  <Separator/>
  <Action name="decreaseindent"/>
  <Action name="increaseindent"/>
  <Action name="precplus"/>
  <Action name="precminus"/>
  <Separator/>
  <Action name="changeangle"/>
 </Menu>
 <Menu name="Data"><text>&amp;Data</text>
  <Action name="sort"/>
  <Action name="textToColumns"/>
  <Separator/>
  <Action name="insertColumn"/>
  <Action name="insertRow"/>
  <Action name="deleteColumn"/>
  <Action name="deleteRow"/>
  <Separator/>
  <Action name="insertCell"/>
  <Action name="removeCell"/>
  <Separator/>
  <Action name="mergecell"/>
  <Action name="dissociatecell"/>
  <Separator/>
  <Action name="showArea"/>
  <Separator/>
  <Action name="subtotals"/>
  <Action name="goalSeek"/>
  <Action name="consolidate"/>
 </Menu>
 <Menu name="tools"><text>&amp;Tools</text>
  <Action name="spelling"/>
  <Separator/>
  <Action name="sortlist"/>
  <Menu name="Protect"><text>&amp;Protect Document</text>
    <Action name="protectSheet"/>
    <Action name="protectDoc"/>
  </Menu>
  <Separator/>
  <Action name="RecalcWorkSheet"/>
  <Action name="RecalcWorkBook"/>
  <Separator/>
 </Menu>
 <Menu name="settings"><text>&amp;Settings</text>
  <Separator group="settings_show"/>
  <Action name="preference" group="settings_configure"/>
 </Menu>
</MenuBar>
<Menu name="calc_popup">
 <Action name="menu_sum"/>
 <Action name="menu_min"/>
 <Action name="menu_max"/>
 <Action name="menu_average"/>
 <Action name="menu_count"/>
 <Action name="menu_none"/>
</Menu>
<ToolBar fullWidth="true" name="editAndColumnAndSortAndPartToolBar"><text>Edit</text>
 <Action name="undo"/>
 <Action name="redo"/>
 <Separator/>
 <Action name="cut"/>
 <Action name="copy"/>
 <Action name="paste"/>
 <Separator/>
 <Action name="view_zoom"/>
 <Separator/>
 <Action name="insertColumn"/>
 <Action name="insertRow"/>
 <Action name="deleteColumn"/>
 <Action name="deleteRow"/>
 <Separator/>
 <Action name="sortInc"/>
 <Action name="sortDec"/>
 <Separator/>
 <Action name="insertChart"/>
 <Action name="insertPart"/>
 <Action name="transform"/>
</ToolBar>
<ToolBar fullWidth="true" name="mathToolBar"><text>Math</text>
 <Action name="autoSum"/>
 <Action name="insertMathExpr"/>
 <Action name="formulaSelection"/>
</ToolBar>
<ToolBar fullWidth="true" name="fontPropertyToolBar"><text>Format</text>
 <Action name="selectFont"/>
 <Action name="selectFontSize"/>
 <Separator/>
 <Action name="textColor"/>
 <Action name="bold"/>
 <Action name="italic"/>
 <Action name="underline"/>
 <Separator/>
 <Action name="left"/>
 <Action name="center"/>
 <Action name="right"/>
 <Separator/>
 <Action name="top"/>
 <Action name="middle"/>
 <Action name="bottom"/>
 <Action name="multiRow"/>
 <Separator/>
 <Action name="percent"/>
 <Action name="precplus"/>
 <Action name="precminus"/>
 <Action name="money"/>
 <Separator/>
 <Action name="decreaseindent"/>
 <Action name="increaseindent"/>
</ToolBar>
<ToolBar fullWidth="true" hidden="true" name="colorAndBorderToolBar"><text>Color/Border</text>
 <Action name="borderLeft"/>
 <Action name="borderTop"/>
 <Action name="borderRight"/>
 <Action name="borderBottom"/>
 <Action name="borderOutline"/>
 <Action name="borderAll"/>
 <Action name="borderRemove"/>
 <Action name="borderColor"/>
 <Separator/>
 <Action name="dissociatecell"/>
 <Action name="mergecell"/>
 <Separator/>
 <Action name="backgroundColor"/>
</ToolBar>
<Menu name="menupage_popup">
  <Action name="renameTable"/>
  <Action name="insertTable"/>
  <Action name="removeTable"/>
  <Action name="hideTable"/>
  <Action name="showTable"/>
</Menu>
</kpartgui>
