<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" ><kpartgui name="KChart" version="12">
<MenuBar>
 <Menu name="Edit"><text>&amp;Edit</text>
  <Action name="edit"/>
  <Action name="config"/>
  <Separator />
  <Action name="page_layout"/>
 </Menu>
 <Menu name="settings"><text>&amp;Settings</text>
  <Separator group="settings_show"/>
  <Action name="loadconfig" group="settings_show"/>
  <Action name="saveconfig" group="settings_show"/>
  <Action name="defaultconfig" group="settings_show"/>
  <Separator group="settings_show"/>
 </Menu>
</MenuBar>
<ToolBar name="KChartToolBar"><Text>Chart</Text>
 <Action name="edit"/>
 <Action name="config"/>
 <Action name="wizard"/>
 <Action name="piechart"/>
 <Action name="linechart"/>
 <Action name="areaschart"/>
 <Action name="barschart"/>
 <Action name="hilochart"/>
 <Action name="ringchart"/>
 <Action name="polarchart"/>
 <Action name="bwchart"/>
</ToolBar>
<Menu name="action_popup">
 <Action name="config"/>
 <Separator />
 <Action name="color_config"/>
 <Action name="font_config"/>
 <Action name="back_config"/>
 <Action name="legend_config"/>
 <Action name="headerfooter_subtype"/>
 <Action name="legend_subtype"/>
 <Separator />
 <Action name="edit"/>
</Menu>
</kpartgui>
