<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" >
<kpartgui name="KivioSelectTool" library="libkivioselecttool" version="2">
<MenuBar>
  <Menu name="Tools">
    <Action name="select" />
  </Menu>
</MenuBar>
</kpartgui>
