<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" ><kpartgui name="KWord" version="94">
<MenuBar>
 <Menu name="file"><text>&amp;File</text>
  <Action name="extra_template"/>
  <Separator/>
  <Action name="file_statistics"/>
 </Menu>
 <Menu name="edit"><text>&amp;Edit</text>
  <Action name="koffice_undo"/>
  <Action name="koffice_redo"/>
  <Separator/>
  <Action name="edit_cut"/>
  <Action name="edit_copy"/>
  <Action name="edit_paste"/>
  <Action name="edit_selectall"/>
  <Separator/>
  <Action name="edit_find"/>
  <Action name="edit_findnext"/>
  <Action name="edit_findprevious"/>
  <Action name="edit_replace"/>
  <Separator/>
  <Action name="delete_page"/>
 </Menu>
 <Menu name="view"><text>&amp;View</text>
  <Action name="view_newview"/>
  <ActionList name="view_closeallviews"/>
  <Separator/>
  <ActionList name="view_split" />
  <Action name="view_pagemode"/>
  <Action name="view_previewmode"/>
  <Action name="view_textmode"/>
  <Separator/>
  <Action name="view_formattingchars"/>
  <Action name="view_frameborders"/>
  <Separator/>
  <Action name="show_docstruct"/>
  <Action name="show_ruler"/>
  <Separator/>
  <Action name="view_zoom"/>
 </Menu>
 <Menu name="insert"><text>&amp;Insert</text>
  <!-- Inside the text, simple things (e.g. one char) -->
  <Action name="insert_specialchar"/>
  <Action name="insert_framebreak"/>
  <!-- Code for horizontal line is broken
  <Action name="insert_horizontal_line"/>
  -->
  <Action name="insert_page"/>
  <Separator/>
  <!-- Inside the text, more -->
  <Action name="insert_footendnote"/>
  <Action name="insert_contents"/>
  <Action name="insert_variable"/> <!-- menu -->
  <Action name="insert_expression"/> <!-- menu -->
  <Action name="insert_link"/>
  <Action name="insert_comment"/>
  <Action name="insert_file"/>
  <Action name="add_bookmark"/>
  <Separator/>
  <!-- Frames - the order matches the order of the keybindings -->
  <Action name="tools_createtext"/>
  <Action name="insert_picture"/>
  <Action name="tools_formula"/>
  <Action name="insert_table"/>
  <Action name="tools_part"/>
 </Menu>
 <Menu name="format"><text>F&amp;ormat</text>
  <Action name="text_default"/>
  <Action name="format_font"/>
  <Action name="format_paragraph"/>
  <Separator/>
  <Action name="format_page"/>
  <Separator/>
  <Action name="format_stylist"/>
  <Action name="import_style"/>
  <Action name="create_style"/>
  <Action name="format_stylemenu"/>
  <Action name="format_footendnote"/>
  <Menu name="Formula"><text>Formula</text>
    <Menu name="matrix"><text>Matrix</text>
     <Action name="formula_insertcolumn"/>
     <Action name="formula_appendcolumn"/>
     <Action name="formula_removecolumn"/>
     <Action name="formula_insertrow"/>
     <Action name="formula_appendrow"/>
     <Action name="formula_removerow"/>
    </Menu>
    <Action name="formula_addupperindex"/>
    <Action name="formula_addlowerindex"/>
    <Action name="formula_addnegthinspace"/>
    <Action name="formula_addthinspace"/>
    <Action name="formula_addmediumspace"/>
    <Action name="formula_addthickspace"/>
    <Action name="formula_addquadspace"/>
    <Action name="formula_removeenclosing"/>
    <Action name="formula_makegreek"/>
    <Action name="formula_insertsymbol"/>
    <Separator/>
    <Action name="formula_syntaxhighlighting"/>
 </Menu>
  <Separator/>
  <Action name="format_header"/>
  <Action name="format_footer"/>
 </Menu>
 <Menu name="frames"><text>Fra&amp;mes</text>
  <Action name="format_frameset"/>
  <Action name="edit_delframe"/>
  <Separator/>
  <Action name="raiseframe"/>
  <Action name="lowerframe"/>
  <Action name="bring_tofront_frame"/>
  <Action name="send_toback_frame"/>
  <Separator/>
  <Action name="create_linked_frame"/>
  <Action name="convert_to_text_box"/>
  <Separator/>
  <Action name="frame_stylist"/>
  <Action name="create_framestyle"/>
  <Action name="frame_stylemenu"/>
  <!--<Action name="border_color"/> Can't do that while we're sharing the action with paragraphs-->
  <Action name="border_backgroundcolor"/>
  <Menu name="FrameBorders"><text>Configure Frame Borders</text>
   <Action name="border_outline"/>
   <Action name="border_left"/>
   <Action name="border_right"/>
   <Action name="border_top"/>
   <Action name="border_bottom"/>
   <Action name="border_style"/>
   <Action name="border_color"/>
  </Menu>
 </Menu>
 <Menu name="table"><text>Ta&amp;ble</text>
  <Action name="table_propertiesmenu"/>
  <Separator/>
  <Menu name="Row"><text>Row</text>
 	 <Action name="table_insrow"/>
	 <Action name="table_delrow"/>
  </Menu>
  <Menu name="Column"><text>Column</text>
  	<Action name="table_inscol"/>
	<Action name="table_delcol"/>
	<Action name="table_resizecol"/>
  </Menu>
  <Separator/>
  <Menu name="Cell"><text>Cell</text>
	  <Action name="table_joincells"/>
	  <Action name="table_splitcells"/>
  	  <Action name="table_protectcells"/>
  </Menu>
  <Action name="table_ungroup"/>
  <Separator/>
  <Action name="table_delete"/>
  <Separator/>
  <Action name="table_stylist"/>
  <Action name="table_stylemenu"/>
  <Action name="convert_table_to_text"/>
 </Menu>
 <Menu name="tools"><text>&amp;Tools</text>
  <Menu name="SpellCheck"><text>Spellcheck</text>
	  <Action name="tool_auto_spellcheck"/>
	  <Action name="extra_spellcheck"/>
  </Menu>
  <Menu name="AutoFormat"><text>Autocorrection</text>
	<Action name="enable_autocorrection"/>
  	<Action name="apply_autoformat"/>
  </Menu>
  <Separator/>
  <Action name="change_case"/>
  <Action name="sort_text"/>
  <Action name="personal_expr"/>
  <Action name="add_personal_expression"/>
  <Action name="custom_vars"/>
  <Action name="select_bookmark"/>
  <ActionList name="datatools"/>
  <Separator/>
  <Action name="edit_sldatabase"/>
 </Menu>
 <Menu name="settings"><text>&amp;Settings</text>
  <Separator group="settings_show"/>
  <Action name="direct_cursor" group="settings_show"/>
  <Separator group="settings_show"/>
  <Action name="configure_autocorrection" group="settings_show"/>
  <Action name="configure_completion" group="settings_show"/>
  <Action name="configure_footendnote" group="settings_show"/>
  <Separator group="settings_show"/>
  <Action name="configure" group="settings_configure"/>
 </Menu>
</MenuBar>
<ToolBar name="edit_toolbar" position="top"><Text>Edit</Text>
  <Action name="koffice_undo"/>
  <Action name="koffice_redo"/>
  <Separator/>
  <Action name="edit_cut"/>
  <Action name="edit_copy"/>
  <Action name="edit_paste"/>
  <Separator/>
  <Action name="extra_spellcheck"/>
  <Action name="edit_find"/>
  <Separator/>
  <Action name="view_zoom"/>
</ToolBar>
<ToolBar hidden="true" name="table_toolbar" position="top"><Text>Table</Text>
  <Action name="table_properties"/>
  <Separator/>
  <Action name="table_style"/>
  <Separator/>
  <Action name="table_insrow"/>
  <Action name="table_inscol"/>
  <Action name="table_delrow"/>
  <Action name="table_delcol"/>
</ToolBar>
<ToolBar name="insert_toolbar" position="left"><Text>Insert</Text>
  <Action name="insert_table"/>
  <Action name="insert_picture"/>
  <!-- Action name="insert_clipart"/>
  <Separator/>
  <Action name="insert_specialchar"/ -->
  <Separator/>
  <Action name="tools_createtext"/>
  <Action name="tools_createpix"/>
  <Action name="tools_formula"/>
  <Action name="tools_part"/>
</ToolBar>
<ToolBar name="paragraph_toolbar" position="top"><Text>Paragraph</Text>
  <Action name="format_style"/>
  <Separator/>
  <Action name="format_alignleft"/>
  <Action name="format_aligncenter"/>
  <Action name="format_alignright"/>
  <Action name="format_alignblock"/>
  <Separator/>
  <Action name="format_number"/>
  <Action name="format_bullet"/>
  <Separator/>
  <Action name="format_decreaseindent"/>
  <Action name="format_increaseindent"/>
</ToolBar>
<ToolBar name="format_toolbar" position="top"><Text>Format</Text>
  <Action name="format_fontfamily"/>
  <Action name="format_fontsize"/>
  <Separator/>
  <Action name="format_bold"/>
  <Action name="format_italic"/>
  <Action name="format_underline"/>
  <Action name="format_strike"/>
  <Separator/>
  <Action name="format_super"/>
  <Action name="format_sub"/>
  <Separator/>
  <Action name="format_color"/>
</ToolBar>
<ToolBar hidden="true" name="border_toolbar" position="top"><Text>Borders</Text>
  <Action name="frame_style"/>
  <Action name="border_outline"/>
  <Action name="border_left"/>
  <Action name="border_right"/>
  <Action name="border_top"/>
  <Action name="border_bottom"/>
  <Action name="border_width"/>
  <Action name="border_style"/>
  <Action name="border_color"/>
  <Action name="border_backgroundcolor"/>
</ToolBar>
<!--
<ToolBar hidden="true" name="mailmerge_toolbar" position="top"><Text>MailMerge</Text>
  <Action name="mailmerge_draglabel"/>
  <Action name="mailmerge_varchooser"/>
  <Action name="edit_sldatabase"/>
</ToolBar>
-->
<ToolBar hidden="true" name="formula_toolbar" position="bottom"><Text>Formula</Text>
  <Action name="formula_addtext"/>
  <Action name="formula_addroot"/>
  <Action name="formula_addfrac"/>
  <Action name="formula_addbra"/>
  <Action name="formula_addsqrbra"/>
  <Action name="formula_addcurbra"/>
  <Action name="formula_addabsbra"/>
  <Action name="formula_addoverline"/>
  <Action name="formula_addunderline"/>
  <Action name="formula_addintegral"/>
  <Action name="formula_addsum"/>
  <Action name="formula_addproduct"/>
  <Action name="formula_addmatrix"/>
  <Action name="formula_addupperleft"/>
  <Action name="formula_addlowerleft"/>
  <Action name="formula_addupperright"/>
  <Action name="formula_addlowerright"/>
  <Action name="formula_typeleft"/>
  <Action name="formula_typeright"/>
  <Separator/>
  <Action name="formula_symbolnames"/>
  <Action name="formula_insertsymbol"/>
  <Separator/>
  <Action name="formula_insertcolumn"/>
  <Action name="formula_appendcolumn"/>
  <Action name="formula_removecolumn"/>
  <Action name="formula_insertrow"/>
  <Action name="formula_appendrow"/>
  <Action name="formula_removerow"/>
</ToolBar>
<StatusBar/>
<Menu name="text_popup">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <ActionList name="datatools"/>
 <ActionList name="tableactions"/>
</Menu>
<Menu name="text_popup_spell">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <ActionList name="datatools"/>
 <Action name="ignore_all"/>
 <Action name="add_word_to_dictionary"/>
 <ActionList name="tableactions"/>
</Menu>
<Menu name="text_popup_spell_with_result">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <ActionList name="datatools"/>
 <Action name="ignore_all"/>
 <Action name="add_word_to_dictionary"/>
 <ActionList name="tableactions"/>
 <Separator/>
 <Menu name="check_spell_list"><text>Spell Check Result</text>
   <ActionList name="spell_result_action"/>
 </Menu>
</Menu>
<Menu name="custom_var_popup">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="edit_customvars"/>
 <!--<ActionList name="datatools"/> Spell check doesn't work for variables (yet?)-->
</Menu>
<Menu name="variable_popup">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Menu name="variable_list"><text>Change Variable To</text>
  <ActionList name="variable_action"/>
 </Menu>
 <!--<ActionList name="datatools"/> Spell check doesn't work on variables (yet?)-->
</Menu>
<Menu name="text_popup_link">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="open_link"/>
 <Action name="change_link"/>
 <Action name="copy_link"/>
 <Action name="remove_link"/>
 <Action name="add_to_bookmark"/>
 <!--<ActionList name="datatools_link"/> Spell check doesn't work on links (yet?)-->
</Menu>
<Menu name="footnote_popup">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="edit_footendnote"/>
 <Action name="change_footendtype"/>
 <!--<ActionList name="datatools"/> Spell check doesn't work for variables (yet?)-->
</Menu>
<Menu name="comment_popup">
 <Action name="text_default"/>
 <Action name="format_font"/>
 <Action name="format_paragraph"/>
 <Separator/>
 <Action name="border_backgroundcolor"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="edit_comment"/>
 <Action name="remove_comment"/>
 <Action name="copy_text_comment"/>
 <ActionList name="datatools"/>
 <ActionList name="spell_action"/>
</Menu>
<Menu name="action_popup">
  <Action name="tools_createtext"/>
  <Action name="tools_createpix"/>
  <Action name="tools_table"/>
  <Action name="tools_kspreadtable"/>
  <Action name="tools_formula"/>
  <Action name="tools_part"/>
</Menu>
<Menu name="frame_popup">
 <Action name="edit_delframe"/>
 <Separator/> 
 <Action name="create_framestyle"/>
 <Action name="border_backgroundcolor"/>
 <Menu name="FrameBorders"><text>Configure Frame Borders</text>
  <Action name="border_outline"/>
  <Action name="border_left"/>
  <Action name="border_right"/>
  <Action name="border_top"/>
  <Action name="border_bottom"/>
  <Action name="border_style"/>	
  <Action name="border_color"/>
  </Menu>
 <Separator/> 
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <ActionList name="frameset_type_action"/> <!-- Used for frameset type (picture, part...) spesific actions -->
 <Action name="format_frameset"/>
</Menu>
<Menu name="frame_popup_table">
 <Action name="format_frameset"/>
 <Action name="edit_delframe"/>
 <Action name="create_framestyle"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Menu name="Cell"><text>Cell</text>
	 <Action name="table_joincells"/>
	 <Action name="table_splitcells"/>
	 <Action name="table_protectcells"/>
 </Menu>
 <Separator/>
 <Menu name="Row"><text>Row</text>
	 <Action name="table_insrow"/>
	 <Action name="table_delrow"/>
 </Menu>  
 <Menu name="Column"><text>Column</text>
	 <Action name="table_inscol"/>
	 <Action name="table_delcol"/>
	 <Action name="table_resizecol"/>
 </Menu>
 <Separator/>
 <Menu name="TableBorders"><text>Configure Table Borders</text>
  <Action name="border_outline"/>
  <Action name="border_left"/>
  <Action name="border_right"/>
  <Action name="border_top"/>
  <Action name="border_bottom"/>
  <Action name="border_style"/>	
  <Action name="border_color"/>
  </Menu>
 <Action name="table_ungroup"/>
</Menu>
<Menu name="docstruct_popup">
  <ActionList name="edit_action"/>
  <Action name="select_frameset"/>
  <Action name="delete_frameset"/>
  <Action name="edit_frameset_properties"/>
</Menu>
</kpartgui>

