<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" >
<kpartgui name="KivioZoomTool" library="libkiviozoomtool" version="6">
<ToolBar name="ZoomToolBar" fullWidth="false" position="left" hidden="true"><text>Zoom Tool</text>
  <Action name="zoom"/>
  <Action name="zoomHand"/>
  <Separator lineSeparator="true" />
  <Action name="zoomPlus"/>
  <Action name="zoomMinus"/>
  <Separator lineSeparator="true" />
  <Action name="zoomWidth"/>
  <Action name="zoomHeight"/>
  <Action name="zoomPage"/>
  <Separator lineSeparator="true" />
  <Action name="zoomSelected"/>
  <Action name="zoomAllObjects"/>
</ToolBar>
<MenuBar>
 <Menu name="View">
   <Menu name="Zoom"><text>&amp;Zoom Tool</text>
    <Action name="zoom"/>
    <Action name="zoomHand"/>
    <Action name="zoomPlus"/>
    <Action name="zoomMinus"/>
    <Action name="zoomWidth"/>
    <Action name="zoomHeight"/>
    <Action name="zoomPage"/>
    <Action name="zoomSelected"/>
    <Action name="zoomAllObjects"/>
   </Menu>
 </Menu>
 <Menu name="Tools">
  <Action name="zoom"/>
  <Action name="zoomHand"/>
 </Menu>
</MenuBar>
</kpartgui>
