<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd" ><kpartgui name="kivio" version="16">
<MenuBar>
 <Menu name="Edit"><text>&amp;Edit</text>
  <Action name="edit_undo"/>
  <Action name="edit_redo"/>
  <Separator/>
   <Action name="cutStencil"/>
   <Action name="copyStencil"/>
   <Action name="pasteStencil"/>
   <Separator/>
   <Action name="selectAllStencils"/>
   <Action name="unselectAllStencils"/>
   <Separator/>
 </Menu>
 <Menu name="View"><text>&amp;View</text>
   <Action name="view_newview"/>
   <ActionList name="view_closeallviews"/>
   <Separator/>
   <ActionList name="view_split"/>
   <Action name="showPageBorders"/>
   <Action name="showPageMargins"/>
   <Separator/>
   <Action name="showRulers"/>
   <Action name="showGrid"/>
   <Action name="showGuides"/>
   <Separator/>
   <Action name="snapGrid"/>
   <Action name="snapGuides"/>
   <Separator/>
   <Action name="viewZoom"/>
   <Separator/>
   <Menu name="Docker"><text>&amp;Docker</text>
     <Action name="stencilGeometry"/>
     <Action name="layersPanel"/>
     <Action name="viewManager"/>
     <Action name="birdEye"/>
     <Action name="protection"/>
   </Menu>
 </Menu> <Menu name="Page"><text>P&amp;age</text>
   <Action name="insertPage"/>
   <Action name="removePage"/>
   <Separator/>
   <Action name="hidePage"/>
   <Action name="showPage"/>
   <Separator/>
   <Action name="exportPage"/>
 </Menu>
 <Menu name="Format"><text>F&amp;ormat</text>
   <Action name="textFormat"/>
   <Action name="stencilFormat"/>
   <Action name="arrowHeadFormat"/>
   <Separator/>
   <Action name="paperLayout"/>
   <Separator/>
   <Action name="alignStencils"/>
   <Separator/>
   <Action name="groupStencils"/>
   <Action name="ungroupStencils"/>
   <Separator/>
   <Action name="sendStencilToBack"/>
   <Action name="bringStencilToFront"/>
   <Separator/>
 </Menu>
 <Menu name="Tools"><text>&amp;Tools</text>
 <Action name="addStencilSet"/>
 </Menu>
 <Menu name="settings"><text>&amp;Settings</text>
   <Separator group="settings_show"/>
   <Action name="options" group="settings_configure"/>
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar" fullWidth="false"><text>File</text>
  <Separator/>
  <Action name="addStencilSet"/>
</ToolBar>
<ToolBar name="EditToolBar" fullWidth="false"><text>Edit</text>
  <Action name="edit_undo"/>
  <Action name="edit_redo"/>
  <Separator/>
  <Action name="cutStencil"/>
  <Action name="copyStencil"/>
  <Action name="pasteStencil"/>
  <Separator/>
  <Action name="viewZoom"/>
</ToolBar>
<ToolBar name="FormatToolBar" fullWidth="false"><text>Format</text>
  <Action name="arrowHeads"/>
  <Separator lineSeparator="true" />
  <Action name="setFGColor"/>
  <Action name="setBGColor"/>
  <Separator lineSeparator="true" />
  <Action name="setLineWidth"/>
</ToolBar>
<ToolBar name="TextBar" fullWidth="false"><text>Text Format</text>
  <Action name="setFontFamily"/>
  <Action name="setFontSize"/>
  <Separator lineSeparator="true" />
  <Action name="setTextColor"/>
  <Separator lineSeparator="true" />
  <Action name="setFontBold"/>
  <Action name="setFontItalics"/>
  <Action name="setFontUnderline"/>
  <Separator lineSeparator="true" />
  <Action name="setHTextAlignment"/>
  <Action name="setVTextAlignment"/>
  <Action name="textAlignLeft"/>
  <Action name="textAlignCenter"/>
  <Action name="textAlignRight"/>
  <Action name="textVAlignSuper"/>
  <Action name="textVAlignSub"/>
</ToolBar>
<ToolBar name="ToolsToolBar" fullWidth="false" position="left"><text>Tools</text>
</ToolBar>
<Menu name="menupage_popup">
  <Action name="renamePage"/>
  <Action name="insertPage"/>
  <Action name="removePage"/>
</Menu>
<Menu name="select_popup">
  <Action name="text"/>
  <Separator/>
  <Action name="cutStencil"/>
  <Action name="copyStencil"/>
  <Action name="pasteStencil"/>
  <Separator/>
  <Action name="alignStencils"/>
  <Separator/>
  <Action name="groupStencils"/>
  <Action name="ungroupStencils"/>
  <Separator/>
  <Action name="sendStencilToBack"/>
  <Action name="bringStencilToFront"/>
  <Separator/>
</Menu>
</kpartgui>
