/* -*- Mode: C++ -*-
   KDChart - a multi-platform charting engine
   */

/****************************************************************************
 ** Copyright (C) 2001-2003 Klarälvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KDChart library.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
 ** Licensees holding valid commercial KDChart licenses may use this file in
 ** accordance with the KDChart Commercial License Agreement provided with
 ** the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.klaralvdalens-datakonsult.se/?page=products for
 **   information about KDChart Commercial License Agreements.
 **
 ** Contact info@klaralvdalens-datakonsult.se if any conditions of this
 ** licensing are not clear to you.
 **
 **********************************************************************/
#ifndef __KDCHARTTABLE_H__
#define __KDCHARTTABLE_H__

// *must* include this one as first one:
#include <KDChartGlobal.h>

#include <KDChartListTable.h>
#if COMPAT_QT_VERSION >= 0x030000
#ifdef Q_WS_WIN
#pragma message( "*** KDChartTable.h: Including KDChartVectorTable.h ***" )
#endif
#include <KDChartVectorTable.h>
#else
#ifdef Q_WS_WIN
#pragma message( "*** KDChartTable.h:  N O T  including KDChartVectorTable.h ***" )
#endif
#endif

#if COMPAT_QT_VERSION >= 0x030000
typedef KDChartVectorTableData KDChartTableData;
#else
typedef KDChartListTableData KDChartTableData;
#endif


#endif
